
# Slot: regulated by




URI: [biolink:regulated_by](https://w3id.org/biolink/vocab/regulated_by)


## Domain and Range

[PhysicalEssenceOrOccurrent](PhysicalEssenceOrOccurrent.md) &#8594;  <sub>0..1</sub> [PhysicalEssenceOrOccurrent](PhysicalEssenceOrOccurrent.md)

## Parents


## Children

 *  [negatively regulated by](negatively_regulated_by.md)
 *  [positively regulated by](positively_regulated_by.md)

## Used by

